@@ -733,6 +733,18 @@ Options -Indexes
             throw new Exception("No admin username found for this WordPress site");
         }
         
+        // First, ensure the wp-cli-login-command plugin is installed and activated
+        $installCmd = "wp login install --activate";
+        $installResult = $this->execWpCli($site['container_name'], $site['user'], $installCmd, $path);
+        
+        // If installation fails, try to continue anyway (plugin might already be installed)
+        if (!$installResult['success'] && !strpos($installResult['output'], 'already installed')) {
+            // Only throw error if it's not already installed
+            if (!strpos($installResult['output'], 'already installed') && !strpos($installResult['output'], 'already active')) {
+                throw new Exception("Failed to install login plugin: " . $installResult['output']);
+            }
+        }
+        
         // Create magic login link using wp-cli-login-command plugin
         $cmd = "wp login create " . escapeshellarg($adminUsername);
         $result = $this->execWpCli($site['container_name'], $site['user'], $cmd, $path);
